#
# spec file for package python-relatorio
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2016-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15allpythons}
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         mod_name relatorio
Name:           python-relatorio
Version:        0.11.1
Release:        1.2
Summary:        Python module to create reports from Python objects
License:        GPL-3.0-or-later
Group:          Productivity/Office/Management
URL:            https://pypi.python.org/pypi/relatorio
Source:         https://pypi.io/packages/source/r/%{mod_name}/%{mod_name}-%{version}.tar.gz
BuildRequires:  %{python_module Genshi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-magic}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros

Requires:       python-Genshi
Requires:       python-PyYAML
Requires:       python-lxml
Requires:       python-pycha
Requires:       python-python-magic
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This is a Python module to create reports from Python objects.
Output plugins to several formats are included, such
as documents (odt, ods, pdf) or images (png, svg).

%prep
%setup -q -n %{mod_name}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/relatorio-render

%check
# https://relatorio.tryton.org/bug65
sed -i 's:iteritems:items:' relatorio/tests/test_api.py
mv relatorio relatorio_hide
%pyunittest discover -v

%post
%python_install_alternative relatorio-render

%postun
%python_uninstall_alternative relatorio-render

%files %{python_files}
%license LICENSE
%doc README.rst COPYRIGHT
%python_alternative %{_bindir}/relatorio-render
%{python_sitelib}/relatorio
%{python_sitelib}/relatorio-%{version}*-info

%changelog
* Mon Feb 24 2025 Dirk Müller <dmueller@suse.com>
- update to 0.11.1:
  * Ignore ZipFile compresslevel for Python < 3.7
* Mon Dec  9 2024 Axel Braun <axel.braun@gmx.de>
- version 0.11.0
  * Allow setting zip file generation options on opendocument templates
* Fri Apr  5 2024 Nathan Cutler <ncutler@suse.com>
- spec: use %%{?sle15allpythons} instead of
  %%{?sle15_python_module_pythons} to allow building
  python3-relatorio for SLE15 (bsc#1222362)
* Tue Jan 23 2024 Axel Braun <axel.braun@gmx.de>
- switch to wheel, enable %%{?sle15_python_module_pythons}
* Tue May  3 2022 Axel Braun <axel.braun@gmx.de>
- version 0.10.1
  * Add support for Python 3.10
  * Support directive applying to itself
  * Keep tail of directive
  * Use unittest discover
* Thu Sep 16 2021 pgajdos@suse.com
- python_alternative relatorio-render
* Sun Sep 12 2021 Axel Braun <axel.braun@gmx.de>
- version 0.10.0
  * Add relatorio-render script
  * Add templating of meta in opendocument
  * Remove support for Python older than 3.5
* Mon Sep  6 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Tue Jul 27 2021 Axel Braun <axel.braun@gmx.de>
- version 0.9.3
  * Support empty image in opendocument
  * Add support for Python 3.9
* Mon Jan  4 2021 Axel Braun <axel.braun@gmx.de>
- version 0.9.2
  * Support draw name tuple without parenthesis
* Tue Jan 28 2020 Axel Braun <axel.braun@gmx.de>
- Version 0.9.1
  * Do not guess type of cell if directive is not alone
  * Add support for Python 3.8
  * Support file-magic as fallback to python-magic
* Wed Jul 31 2019 Tomáš Chvátal <tchvatal@suse.com>
- Run tests
- Run fdupes
* Tue Jul 30 2019 Axel Braun <axel.braun@gmx.de>
- version 0.9.0
  * Support out parameter of render
  * Write opendocument stream directly to the ZipFile
* Fri Jul  5 2019 Axel Braun <axel.braun@gmx.de>
- python-magic added to requirements
* Wed Oct  3 2018 Axel Braun <axel.braun@gmx.de>
- version 0.8.1
  * Add support for Python 3.7
  * Escape invalid XML characters
  * Enforce closing tag to be the same directive as the opening
  * Use compression for zip file
  * Write mimetype as first file of the zip file
* Mon Dec 11 2017 tchvatal@suse.com
- Explain why the tests are conditioned around
- Specify all the runtime dependencies based on setup.py
* Sat Dec  9 2017 axel.braun@gmx.de
- version 0.8.0
  * Do not guess_type on styled cell content
  * Remove type attributes when guessing type
  * Add support for Python 3.6
  * Remove soft-page-break
  * tests added to spec file
* Fri Oct 20 2017 axel.braun@gmx.de
- Version 0.7.1 - Bugfix release
  * Remove warning when import plugin fails
  * Apply the guess type function on the correct node
  * Fix guess_type for date and datetime
* Sun Jul 30 2017 axel.braun@gmx.de
- Version 0.7.0
  * Replace hard-coded extensions by mimetypes guess
  * Add more guess types: 'boolean', 'date', 'time' and 'void'
  * Add support for Flat OpenDocument
* Wed Mar  8 2017 axel.braun@gmx.de
- changes for singlespec
* Sun Dec 18 2016 axel.braun@gmx.de
- version 0.6.4
  * Use StringIO instead of BytesIO for TextSerializer result
* Thu Aug 25 2016 axel.braun@gmx.de
- LICENSE file added
* Sun Aug 14 2016 axel.braun@gmx.de
- fixed link to pypi
* Thu Jun 30 2016 axel.braun@gmx.de
- version 0.6.3
  changed naming of .changes file
* Sat Sep 19 2015 axel.braun@gmx.de
- version 0.6.2
* Fri Jul 10 2015 axel.braun@gmx.de
- Version 0.6.1
* Fri Oct 18 2013 p.drouand@gmail.com
- Initial package ( version 0.6.0 )
